@@ -5,8 +5,8 @@
 
 ;; Authors: stardiviner <numbchild@gmail.com>
 ;; Package-Requires: ((emacs "29.1") (nerd-icons "0.1.0") (seq "2.24"))
-;; Package-Version: 20251113.351
-;; Package-Revision: b3a46dc78175
+;; Package-Version: 20260102.1353
+;; Package-Revision: b54d1e296bb0
 ;; Keywords: outline matching hypermedia org
 ;; URL: https://repo.or.cz/org-bookmarks.git
 
@@ -301,8 +301,9 @@ Reset the whole database cache variable when none file select."
                       (completing-read "[org-bookmarks] Select bookmarks from file: "
                                        (seq-filter
                                         (lambda (file) (string-suffix-p ".org" file))
-                                        (list org-bookmarks-file
-                                              (buffer-file-name (current-buffer))))))))
+                                        (append (list org-bookmarks-file
+                                                      (buffer-file-name (current-buffer)))
+                                                (org-files-list)))))))
   (unless (alist-get file org-bookmarks--candidates-cache-alist nil nil 'equal)
     (org-bookmarks-db-cache-update file))
   (if-let* ((file (or file org-bookmarks-file))
